Test for Pico I2S playing capability, based on
# https://www.recantha.co.uk/blog/?p=20950
# and https://gist.github.com/dglaude/7ce0a284e25015320712dbf5baf2ffc5
# I2S Sound output triggered by a i2c sensor signal (sgp30 eCO2 sensor)
# SGP30 code adapted from adafruit example

import audiocore
import board
import audiobusio
import time
import digitalio
import busio
import adafruit_sgp30

onboard_led = digitalio.DigitalInOut(board.GP25)  # Pico onboard LED
onboard_led.direction = digitalio.Direction.OUTPUT

bit_clock = board.GP10     # for i2s breakout, pin 12
word_select = board.GP11   # for i2s breakout, pin 14
data_in = board.GP9        # for i2s breakout, pin 15

SCL_0 = board.GP17         # for i2c sensor, pin 22
SDA_0 = board.GP16         # for i2c sensor, pin 21
i2c_0 = busio.I2C(SCL_0, SDA_0, frequency=100000)
sgp30 = adafruit_sgp30.Adafruit_SGP30(i2c_0)
thresh = 800
# set eCO2 threshold value ccording to your needs, base value: 400

# audio settings
wave_file = open("Test2.wav", "rb")
wave = audiocore.WaveFile(wave_file)
audio = audiobusio.I2SOut(bit_clock, word_select, data_in)
gap = 1  # length of pause

def play_wav():  # plays a wav file

    onboard_led.value = True
    audio.play(wave)

    t = time.monotonic()
    while time.monotonic() - t < 6:
        pass

    onboard_led.value = False
    time.sleep(gap)

print("SGP30 serial #", [hex(i) for i in sgp30.serial])

sgp30.iaq_init()
sgp30.set_iaq_baseline(0x8973, 0x8AAE)

elapsed_sec = 0

while True:
    print((sgp30.eCO2, sgp30.TVOC))  # output for mu plotter
    # print("eCO2 = %d ppm \t TVOC = %d ppb" % (sgp30.eCO2, sgp30.TVOC))   # output as text
    time.sleep(1)
    elapsed_sec += 1
    if elapsed_sec > 10:
        elapsed_sec = 0
        print(
            "**** Baseline values: eCO2 = 0x%x, TVOC = 0x%x"
            % (sgp30.baseline_eCO2, sgp30.baseline_TVOC)
        )
    if (sgp30.eCO2 > thresh):    # play sound if eCO2 value above threshold
        play_wav()